import { Group as SharedGroup, Task as SharedTask, Step as SharedStep, User as SharedUser, Note as SharedNote, PrintHistory as SharedPrintHistory } from '@task-receipts/shared';

// Client-specific type extensions
export interface GroupWithTasks extends Omit<SharedGroup, 'created_at' | 'updated_at'> {
  tasks: TaskWithSteps[];
}

export interface TaskWithSteps extends Omit<SharedTask, 'created_at' | 'updated_at' | 'last_printed_at'> {
  steps: StepWithNotes[];
  notes: NoteWithUser[];
  print_count: number;
  last_printed_at: string | null;
}

export interface StepWithNotes extends Omit<SharedStep, 'created_at' | 'updated_at' | 'last_printed_at'> {
  notes: NoteWithUser[];
  print_count: number;
  last_printed_at: string | null;
}

export interface NoteWithUser extends Omit<SharedNote, 'created_at' | 'updated_at'> {
  user?: SharedUser;
}

export interface PrintHistoryWithDetails extends Omit<SharedPrintHistory, 'created_at' | 'updated_at'> {
  user?: SharedUser;
  task?: TaskWithSteps;
  step?: StepWithNotes;
}

// Re-export shared types with client-specific modifications
export type Group = Omit<SharedGroup, 'created_at' | 'updated_at'>;
export type Task = Omit<SharedTask, 'created_at' | 'updated_at' | 'last_printed_at'> & { last_printed_at: string | null };
export type Step = Omit<SharedStep, 'created_at' | 'updated_at' | 'last_printed_at'> & { last_printed_at: string | null };
export type User = Omit<SharedUser, 'created_at' | 'updated_at'>;
export type Note = Omit<SharedNote, 'created_at' | 'updated_at'>;
export type PrintHistory = Omit<SharedPrintHistory, 'created_at' | 'updated_at'>;